@@ -1,6 +1,8 @@
 import warnings
 from itertools import permutations
 
+import io
+import matplotlib.image as mpimg
 import matplotlib.pyplot as plt
 import networkx as nx
 import numpy as np
@@ -10,6 +12,7 @@ from causallearn.graph.Edge import Edge
 from causallearn.graph.Endpoint import Endpoint
 from causallearn.graph.GeneralGraph import GeneralGraph
 from causallearn.graph.GraphNode import GraphNode
+from causallearn.utils.GraphUtils import GraphUtils
 from causallearn.utils.PCUtils.Helper import list_union, powerset
 
 
@@ -35,6 +38,7 @@ class CausalGraph:
         self.redundant_nodes = []  # store the list of redundant nodes (for subgraphs)
         self.nx_graph = nx.DiGraph()  # store the directed graph
         self.nx_skel = nx.Graph()  # store the undirected graph
+        self.labels = {}
         self.prt_m = {}  # store the parents of missingness indicators
         self.mvpc = None
 
@@ -151,6 +155,7 @@ class CausalGraph:
     def to_nx_graph(self):
         """Convert adjmat into a networkx.Digraph object named nx_graph"""
         nodes = range(len(self.G.graph))
+        self.labels = {i:self.G.nodes[i].get_name() for i in nodes}
         self.nx_graph.add_nodes_from(nodes)
         undirected = self.find_undirected()
         directed = self.find_fully_directed()
@@ -179,6 +184,18 @@ class CausalGraph:
         edges = g_to_be_drawn.edges()
         colors = [g_to_be_drawn[u][v]['color'] for u, v in edges]
         pos = nx.circular_layout(g_to_be_drawn)
-        nx.draw(g_to_be_drawn, pos=pos, with_labels=True, edge_color=colors)
+        nx.draw(g_to_be_drawn, pos=pos, with_labels=True, labels=self.labels, edge_color=colors)
         plt.draw()
         plt.show()
+
+    def draw_pydot_graph(self):
+        """Draw nx_graph if skel = False and draw nx_skel otherwise"""
+        warnings.filterwarnings("ignore", category=UserWarning)
+        pyd = GraphUtils.to_pydot(self.G)
+        tmp_png = pyd.create_png(f="png")
+        pyd.write_png("result.png")
+        fp = io.BytesIO(tmp_png)
+        img = mpimg.imread(fp, format='png')
+        plt.axis('off')
+        plt.imshow(img)
+        plt.show()
