@@ -1,16 +1,16 @@
 import time
-from causallearn.utils.PCUtils import Algorithm1, Algorithm2, Algorithm3, Helper
 from itertools import permutations, combinations
-from causallearn.graph.GraphClass import CausalGraph
-from causallearn.graph.Edge import Edge
-from causallearn.graph.Edges import Edges
-from causallearn.graph.Endpoint import Endpoint
-import numpy as np
-from causallearn.utils.cit import fisherz, chisq, gsq, mv_fisherz, kci, mc_fisherz
+
 import networkx as nx
+import numpy as np
+
+from causallearn.graph.GraphClass import CausalGraph
+from causallearn.utils.PCUtils import SkeletonDiscovery, UCSepset, Meek, Helper
+from causallearn.utils.cit import fisherz, mc_fisherz
 
 
-def cdnod(data, c_indx, alpha, indep_test, stable, uc_rule, uc_priority, mvpc=False, correction_name='MV_Crtn_Fisher_Z'):
+def cdnod(data, c_indx, alpha, indep_test, stable, uc_rule, uc_priority, mvpc=False,
+          correction_name='MV_Crtn_Fisher_Z'):
     '''
     Causal discovery from nonstationary/heterogeneous data
     phase 1: learning causal skeleton,
@@ -28,12 +28,12 @@ def cdnod(data, c_indx, alpha, indep_test, stable, uc_rule, uc_priority, mvpc=Fa
     '''
     data_aug = np.concatenate((data, c_indx), axis=1)
     if mvpc:
-        return mvcdnod_alg(data=data_aug, alpha=alpha, indep_test=indep_test, correction_name=correction_name, stable=stable,
-                        uc_rule=uc_rule, uc_priority=uc_priority)
+        return mvcdnod_alg(data=data_aug, alpha=alpha, indep_test=indep_test, correction_name=correction_name,
+                           stable=stable,
+                           uc_rule=uc_rule, uc_priority=uc_priority)
     else:
         return cdnod_alg(data=data_aug, alpha=alpha, indep_test=indep_test, stable=stable, uc_rule=uc_rule,
-                      uc_priority=uc_priority)
-
+                         uc_priority=uc_priority)
 
 
 def cdnod_alg(data, alpha, indep_test, stable, uc_rule, uc_priority):
@@ -71,34 +71,34 @@ def cdnod_alg(data, alpha, indep_test, stable, uc_rule, uc_priority):
     '''
 
     start = time.time()
-    cg_1 = Algorithm1.skeleton_discovery(data, alpha, indep_test, stable)
+    cg_1 = SkeletonDiscovery.skeleton_discovery(data, alpha, indep_test, stable)
 
     # orient the direction from c_indx to X, if there is an edge between c_indx and X
-    c_indx_id = data.shape[1]-1
+    c_indx_id = data.shape[1] - 1
     for i in cg_1.G.get_adjacent_nodes(cg_1.G.nodes[c_indx_id]):
         cg_1.G.add_directed_edge(i, cg_1.G.nodes[c_indx_id])
 
     if uc_rule == 0:
         if uc_priority != -1:
-            cg_2 = Algorithm2.uc_sepset(cg_1, uc_priority)
+            cg_2 = UCSepset.uc_sepset(cg_1, uc_priority)
         else:
-            cg_2 = Algorithm2.uc_sepset(cg_1)
-        cg = Algorithm3.meek(cg_2)
+            cg_2 = UCSepset.uc_sepset(cg_1)
+        cg = Meek.meek(cg_2)
 
     elif uc_rule == 1:
         if uc_priority != -1:
-            cg_2 = Algorithm2.maxp(cg_1, uc_priority)
+            cg_2 = UCSepset.maxp(cg_1, uc_priority)
         else:
-            cg_2 = Algorithm2.maxp(cg_1)
-        cg = Algorithm3.meek(cg_2)
+            cg_2 = UCSepset.maxp(cg_1)
+        cg = Meek.meek(cg_2)
 
     elif uc_rule == 2:
         if uc_priority != -1:
-            cg_2 = Algorithm2.definite_maxp(cg_1, alpha, uc_priority)
+            cg_2 = UCSepset.definite_maxp(cg_1, alpha, uc_priority)
         else:
-            cg_2 = Algorithm2.definite_maxp(cg_1, alpha)
-        cg_before = Algorithm3.definite_meek(cg_2)
-        cg = Algorithm3.meek(cg_before)
+            cg_2 = UCSepset.definite_maxp(cg_1, alpha)
+        cg_before = Meek.definite_meek(cg_2)
+        cg = Meek.meek(cg_before)
     end = time.time()
 
     cg.PC_elapsed = end - start
@@ -106,8 +106,6 @@ def cdnod_alg(data, alpha, indep_test, stable, uc_rule, uc_priority):
     return cg
 
 
-
-
 def mvcdnod_alg(data, alpha, indep_test, correction_name, stable, uc_rule, uc_priority):
     """
     :param data: data set (numpy ndarray)
@@ -144,7 +142,7 @@ def mvcdnod_alg(data, alpha, indep_test, correction_name, stable, uc_rule, uc_pr
 
     ## Step 2:
     ## a) Run PC algorithm with the 1st step skeleton;
-    cg_pre = Algorithm1.skeleton_discovery(data, alpha, indep_test, stable)
+    cg_pre = SkeletonDiscovery.skeleton_discovery(data, alpha, indep_test, stable)
     cg_pre.to_nx_skeleton()
     # print('Finish skeleton search with test-wise deletion.')
 
@@ -154,31 +152,31 @@ def mvcdnod_alg(data, alpha, indep_test, correction_name, stable, uc_rule, uc_pr
 
     ## Step 3: Orient the edges
     # orient the direction from c_indx to X, if there is an edge between c_indx and X
-    c_indx_id = data.shape[1]-1
+    c_indx_id = data.shape[1] - 1
     for i in cg_corr.G.get_adjacent_nodes(cg_corr.G.nodes[c_indx_id]):
         cg_corr.G.add_directed_edge(i, cg_corr.G.nodes[c_indx_id])
 
     if uc_rule == 0:
         if uc_priority != -1:
-            cg_2 = Algorithm2.uc_sepset(cg_corr, uc_priority)
+            cg_2 = UCSepset.uc_sepset(cg_corr, uc_priority)
         else:
-            cg_2 = Algorithm2.uc_sepset(cg_corr)
-        cg = Algorithm3.meek(cg_2)
+            cg_2 = UCSepset.uc_sepset(cg_corr)
+        cg = Meek.meek(cg_2)
 
     elif uc_rule == 1:
         if uc_priority != -1:
-            cg_2 = Algorithm2.maxp(cg_corr, uc_priority)
+            cg_2 = UCSepset.maxp(cg_corr, uc_priority)
         else:
-            cg_2 = Algorithm2.maxp(cg_corr)
-        cg = Algorithm3.meek(cg_2)
+            cg_2 = UCSepset.maxp(cg_corr)
+        cg = Meek.meek(cg_2)
 
     elif uc_rule == 2:
         if uc_priority != -1:
-            cg_2 = Algorithm2.definite_maxp(cg_corr, alpha, uc_priority)
+            cg_2 = UCSepset.definite_maxp(cg_corr, alpha, uc_priority)
         else:
-            cg_2 = Algorithm2.definite_maxp(cg_corr, alpha)
-        cg_before = Algorithm3.definite_meek(cg_2)
-        cg = Algorithm3.meek(cg_before)
+            cg_2 = UCSepset.definite_maxp(cg_corr, alpha)
+        cg_before = Meek.definite_meek(cg_2)
+        cg = Meek.meek(cg_before)
     end = time.time()
 
     cg.PC_elapsed = end - start
@@ -440,5 +438,3 @@ def matrix_diff(cg1, cg2):
                 diff_ls.append((i, j))
                 count += 1
     return count / 2, diff_ls
-
-
