@@ -39,13 +39,13 @@ class BottomUpParceLiNGAM():
             Regressor to compute residuals.
             This regressor object must have ``fit``method and ``predict`` function like scikit-learn's model.
         prior_knowledge : array-like, shape (n_features, n_features), optional (default=None)
-            Prior knowledge used for causal discovery, where ``n_features`` is the number of features.
+            Prior background_knowledge used for causal discovery, where ``n_features`` is the number of features.
 
-            The elements of prior knowledge matrix are defined as follows [1]_:
+            The elements of prior background_knowledge matrix are defined as follows [1]_:
 
             * ``0`` : :math:`x_i` does not have a directed path to :math:`x_j`
             * ``1`` : :math:`x_i` has a directed path to :math:`x_j`
-            * ``-1`` : No prior knowledge is available to know if either of the two cases above (0 or 1) is true.
+            * ``-1`` : No prior background_knowledge is available to know if either of the two cases above (0 or 1) is true.
         """
         # Check parameters
         if regressor is not None:
@@ -66,7 +66,7 @@ class BottomUpParceLiNGAM():
             self._Aknw = check_array(self._Aknw)
             self._Aknw = np.where(self._Aknw < 0, np.nan, self._Aknw)
 
-            # Extract all partial orders in prior knowledge matrix
+            # Extract all partial orders in prior background_knowledge matrix
             self._partial_orders = self._extract_partial_orders(self._Aknw)
 
     def fit(self, X):
@@ -90,11 +90,11 @@ class BottomUpParceLiNGAM():
         X = check_array(X)
         n_features = X.shape[1]
 
-        # Check prior knowledge
+        # Check prior background_knowledge
         if self._Aknw is not None:
             if (n_features, n_features) != self._Aknw.shape:
                 raise ValueError(
-                    'The shape of prior knowledge must be (n_features, n_features)')
+                    'The shape of prior background_knowledge must be (n_features, n_features)')
 
         # Center variables for each group
         X = X - np.tile(np.mean(X, axis=0), (X.shape[0], 1))
@@ -118,7 +118,7 @@ class BottomUpParceLiNGAM():
         return self._estimate_adjacency_matrix(X, prior_knowledge=self._Aknw)
 
     def _extract_partial_orders(self, pk):
-        """ Extract partial orders from prior knowledge."""
+        """ Extract partial orders from prior background_knowledge."""
         path_pairs = np.array(np.where(pk == 1)).transpose()
         no_path_pairs = np.array(np.where(pk == 0)).transpose()
 
@@ -128,7 +128,7 @@ class BottomUpParceLiNGAM():
             pairs, counts = np.unique(check_pairs, axis=0, return_counts=True)
             if len(pairs[counts > 1]) > 0:
                 raise ValueError(
-                    f'The prior knowledge contains inconsistencies at the following indices: {pairs[counts > 1].tolist()}')
+                    f'The prior background_knowledge contains inconsistencies at the following indices: {pairs[counts > 1].tolist()}')
 
         # Check for inconsistencies in pairs without path
         # If there are duplicate pairs without path, they cancel out and are not ordered.
@@ -141,8 +141,8 @@ class BottomUpParceLiNGAM():
 
         check_pairs = np.concatenate([path_pairs, no_path_pairs[:, [1, 0]]])
         if len(check_pairs) == 0:
-            # If no pairs are extracted from the specified prior knowledge, 
-            # discard the prior knowledge.
+            # If no pairs are extracted from the specified prior background_knowledge,
+            # discard the prior background_knowledge.
             self._Aknw = None
             return None
 
@@ -151,7 +151,7 @@ class BottomUpParceLiNGAM():
 
     def _search_candidate(self, U):
         """ Search for candidate features """
-        # If no prior knowledge is specified, nothing to do.
+        # If no prior background_knowledge is specified, nothing to do.
         if self._Aknw is None:
             return U
 
@@ -283,7 +283,7 @@ class BottomUpParceLiNGAM():
             Training data, where n_samples is the number of samples
             and n_features is the number of features.
         prior_knowledge : array-like, shape (n_variables, n_variables), optional (default=None)
-            Prior knowledge matrix.
+            Prior background_knowledge matrix.
 
         Returns
         -------
@@ -301,7 +301,7 @@ class BottomUpParceLiNGAM():
             # Flatten the array into one dimension
             predictors = self._flatten(self._causal_order[:i])
 
-            # Exclude variables specified in no_path with prior knowledge
+            # Exclude variables specified in no_path with prior background_knowledge
             if prior_knowledge is not None:
                 predictors = [p for p in predictors if pk[target, p] != 0]
 
